@@ -29,14 +29,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
+
 // The following require statements MUST be executed before any others - BEGIN
 require('./exit_on_warning');
-
-require('./harden'); // The following require statements MUST be executed before any others - END
-
+require('./harden');
+// The following require statements MUST be executed before any others - END
 
 require('symbol-observable');
-
 require('source-map-support/register');
-
-require('./root');
\ No newline at end of file
+require('./root');
+require('./node_version_validator');
\ No newline at end of file
